@@ -1,12 +1,12 @@
 package Tk::TIFF;
 require DynaLoader;
 use Tk 800.014;
-require Tk::Photo;
+use Tk::Photo;
 
 use vars qw($VERSION @ISA);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.06';
+$VERSION = '0.09';
 
 bootstrap Tk::TIFF $Tk::VERSION;
 
